@@ -1,16 +1,16 @@
-# encoding: utf-8
+# frozen_string_literal: true
 
 require 'ffaker/address'
 
 module FFaker
-  # Author wiseleyb<wiseleyb@gmail.com>
   module AddressAU
     include FFaker::Address
 
     extend ModuleUtils
     extend self
 
-    # based on areas labeled state (+act) here: http://en.wikipedia.org/wiki/States_and_territories_of_Australia
+    # based on areas labeled state (+act) here:
+    # http://en.wikipedia.org/wiki/States_and_territories_of_Australia
     STATE = [
       'Australian Capital Territory', 'New South Wales', 'Queensland',
       'South Australia', 'Tasmania', 'Victoria', 'Western Australia'
@@ -102,7 +102,7 @@ module FFaker
 
     def suburb(st_abbr = nil, p_code = nil)
       st_abbr ||= state_abbr
-      p_code  ||= postcode(st_abbr)
+      p_code ||= postcode(st_abbr)
       SUBURB[st_abbr][p_code]
     end
 
@@ -112,11 +112,9 @@ module FFaker
     end
 
     def time_zone(st_abbr = nil)
-      if st_abbr
-        TIME_ZONE[st_abbr]
-      else
-        TIME_ZONE.values.sample
-      end
+      return TIME_ZONE[st_abbr] if st_abbr
+
+      TIME_ZONE.values.sample
     end
   end
 end
