@@ -1,4 +1,4 @@
-# encoding: utf-8
+# frozen_string_literal: true
 
 require 'ffaker/address'
 
@@ -9,7 +9,7 @@ module FFaker
     extend ModuleUtils
     extend self
 
-    POSTAL_CODE_FORMAT = '?#? #?#'.freeze
+    POSTAL_CODE_FORMAT = '?#? #?#'
     POSTAL_CODE_CHARS = %w[A B C E G H J K L M N P R S T V X Y].freeze
     PROVINCE_ABBRS = %w[NL NS PE NB QC ON MB SK AB BC YT NT NU].freeze
 
