@@ -1,4 +1,4 @@
-# encoding: utf-8
+# frozen_string_literal: true
 
 require 'ffaker/address'
 
@@ -15,6 +15,10 @@ module FFaker
 
     alias pincode zip_code
 
+    def city
+      fetch_sample(CITY)
+    end
+
     def state
       fetch_sample(STATE)
     end
