@@ -1,4 +1,4 @@
-# encoding: utf-8
+# frozen_string_literal: true
 
 require 'ffaker/address'
 
@@ -21,8 +21,12 @@ module FFaker
       fetch_sample(STATE)
     end
 
-    def state_abbr
-      fetch_sample(STATE_ABBR)
+    def state_abbr(st_name = nil)
+      return find_abbr(state) unless st_name
+
+      st_name = capitalize_all_words(st_name)
+      check_state_existence(st_name)
+      find_abbr(st_name)
     end
 
     def state_and_territories_abbr
@@ -36,5 +40,21 @@ module FFaker
     def continental_state_abbr
       fetch_sample(CONTINENTAL_STATE_ABBR)
     end
+
+    private
+
+    def check_state_existence(state_name)
+      return if STATE.include?(state_name)
+
+      raise ArgumentError, "Unexpected state name: '#{state_name}'"
+    end
+
+    def find_abbr(state)
+      STATE_ABBR[STATE.index(state)]
+    end
+
+    def capitalize_all_words(string)
+      string.split.map(&:capitalize).join(' ')
+    end
   end
 end
