@@ -1,7 +1,9 @@
-# encoding: utf-8
+# frozen_string_literal: true
 
 module FFaker
   module Book
+    require 'cgi'
+
     extend ModuleUtils
     extend self
 
@@ -32,6 +34,15 @@ module FFaker
       FFaker::Avatar.image(slug, size, format, bgset)
     end
 
+    def orly_cover(name = title, book_author = author, top_text = genre)
+      'https://orly-appstore.herokuapp.com/generate?'\
+        "title=#{CGI.escape(name)}&"\
+        "top_text=#{CGI.escape(top_text)}&"\
+        "author=#{CGI.escape(book_author)}&"\
+        "image_code=#{Random.rand(1..40)}&"\
+        "theme=#{Random.rand(1..16)}"
+    end
+
     private
 
     def simple_title
