@@ -1,4 +1,4 @@
-# encoding: utf-8
+# frozen_string_literal: true
 
 module FFaker
   module Currency
@@ -12,5 +12,9 @@ module FFaker
     def name
       fetch_sample(CURRENCY_NAME)
     end
+
+    def symbol
+      fetch_sample(CURRENCY_SYMBOL)
+    end
   end
 end
