@@ -1,11 +1,14 @@
-# encoding: utf-8
+# frozen_string_literal: true
 
 module FFaker
   module Education
     extend ModuleUtils
     extend self
 
-    MAJOR_ADJ = %w[Business Systems Industrial Medical Financial Marketing Political Social] + ['Human Resource']
+    MAJOR_ADJ = [
+      'Business', 'Systems', 'Industrial', 'Medical', 'Financial', 'Marketing', 'Political',
+      'Social', 'Human Resource'
+    ].freeze
     SCHOOL_PREFIX = %w[Green South North Wind Lake Hill Lark River Red White].freeze
     SCHOOL_ADJ = %w[International Global Polytechnic National].freeze
     SCHOOL_TYPE = %w[School University College Institution Academy].freeze
