@@ -1,4 +1,4 @@
-# encoding: utf-8
+# frozen_string_literal: true
 
 require 'ffaker/name'
 
@@ -29,7 +29,7 @@ module FFaker
 
     def first_name(gender = :any)
       case gender
-      when :any then rand(0..1) == 0 ? first_name(:male) : first_name(:female)
+      when :any then rand(0..1).zero? ? first_name(:male) : first_name(:female)
       when :male then fetch_sample(MALE_FIRST_NAMES)
       when :female then fetch_sample(FEMALE_FIRST_NAMES)
       else
