@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 $LOAD_PATH << File.dirname(__FILE__) + '/../lib'
 require 'ffaker'
 
@@ -15,6 +17,7 @@ def faker_modules
     next if mod == FFaker::ModuleUtils
     next if mod == FFaker::RandomUtils
     next if mod == FFaker::Random
+
     mod
   end.compact
 end
@@ -59,7 +62,7 @@ sections = faker_modules.map do |mod|
     left = "`#{meth}`"
     right = ''
 
-    if arity > 0
+    if arity.positive?
       left = "`#{meth}`(#{Array.new(arity) { '...' }.join(', ')})"
     else
       begin
@@ -71,7 +74,7 @@ sections = faker_modules.map do |mod|
                 else
                   (escape examples.join(', ')).to_s
                 end
-      rescue => e
+      rescue StandardError => e
         right = "#{ICONS[:error]} #{e.class}: #{e.message}"
       end
     end
