@@ -1,9 +1,11 @@
+# frozen_string_literal: true
+
 require 'helper'
 
 class TestAvatar < Test::Unit::TestCase
   include DeterministicHelper
 
-  ROBOHASH = 'https://robohash.org'.freeze
+  ROBOHASH = 'https://robohash.org'
 
   assert_methods_are_deterministic(FFaker::Avatar, :image)
 
@@ -12,7 +14,7 @@ class TestAvatar < Test::Unit::TestCase
   end
 
   def test_avatar
-    assert_match(/\Ahttps:\/\/robohash\.org\/.+\.png\?size=300x300\z/,
+    assert_match(%r{\Ahttps://robohash\.org/.+\.png\?size=300x300\z},
                  @tester.image)
   end
 
