@@ -1,4 +1,4 @@
-# encoding: utf-8
+# frozen_string_literal: true
 
 require 'helper'
 
@@ -9,6 +9,6 @@ class TestBoolean < Test::Unit::TestCase
 
   def test_maybe
     maybe = FFaker::Boolean.maybe
-    assert (maybe == false || maybe == true)
+    assert [true, false].include?(maybe)
   end
 end
