@@ -1,4 +1,4 @@
-# encoding: utf-8
+# frozen_string_literal: true
 
 require 'helper'
 
@@ -7,6 +7,6 @@ class TestCurrency < Test::Unit::TestCase
 
   assert_methods_are_deterministic(
     FFaker::Currency,
-    :code, :name
+    :code, :name, :symbol
   )
 end
