@@ -1,4 +1,4 @@
-# encoding: utf-8
+# frozen_string_literal: true
 
 require 'helper'
 
@@ -19,10 +19,10 @@ class TestFakerFilesystem < Test::Unit::TestCase
   end
 
   def test_mime_type_format
-    assert @tester.mime_type.match(/(.*)\/(.*)+/)
+    assert @tester.mime_type.match(%r{(.*)/(.*)+})
   end
 
   def test_file_name
-    assert @tester.file_name.match(/([a-z\-_]+)(\\|\/)([a-z\-_]+)\.([a-z]+)/)
+    assert @tester.file_name.match(%r{([a-z\-_]+)(\\|/)([a-z\-_]+)\.([a-z]+)})
   end
 end
