@@ -1,4 +1,4 @@
-# encoding: utf-8
+# frozen_string_literal: true
 
 require 'helper'
 
@@ -10,7 +10,7 @@ class TestHipsterIpsum < Test::Unit::TestCase
     :paragraph, :paragraphs, :sentence, :sentences, :word, :words
   )
 
-  TEST_REGEX = /\+1|[ a-z]+/i
+  TEST_REGEX = /\+1|[ a-z]+/i.freeze
 
   def test_paragraph
     assert_match(TEST_REGEX, FFaker::HipsterIpsum.paragraph)
