@@ -1,4 +1,4 @@
-# encoding: utf-8
+# frozen_string_literal: true
 
 require 'helper'
 
@@ -29,7 +29,7 @@ class TestFakerIdentification < Test::Unit::TestCase
   end
 
   def test_ethnicity
-    ethnicity_regex = /\A(African American|Asian\/Pacific Islander|Caucasian|Hispanic|Native American|Multiracial|Other|Prefer not to respond)\z/
+    ethnicity_regex = %r{\A(African American|Asian/Pacific Islander|Caucasian|Hispanic|Native American|Multiracial|Other|Prefer not to respond)\z}
     assert_match(ethnicity_regex, @tester.ethnicity)
   end
 end
