@@ -1,5 +1,4 @@
 # frozen_string_literal: true
-# encoding: UTF-8
 
 require 'helper'
 
@@ -13,7 +12,7 @@ class TestFakerJobVN < Test::Unit::TestCase
   end
 
   def test_title
-    assert @tester.title.length >= 1
+    assert_greater_than_or_equal_to @tester.title.length, 1
   end
 
   def test_nouns
