@@ -1,4 +1,4 @@
-# encoding: utf-8
+# frozen_string_literal: true
 
 require 'helper'
 
@@ -7,8 +7,7 @@ class TestLoremARAR < Test::Unit::TestCase
 
   assert_methods_are_deterministic(
     FFaker::LoremAR,
-    :paragraph, :paragraphs, :sentence, :sentences,
-    :phrase, :phrases, :word, :words
+    :paragraph, :paragraphs, :sentence, :sentences, :phrase, :phrases, :word, :words
   )
 
   def test_paragraph
