@@ -1,4 +1,4 @@
-# encoding: utf-8
+# frozen_string_literal: true
 
 require 'helper'
 
@@ -11,15 +11,15 @@ class TestLoremCN < Test::Unit::TestCase
   )
 
   def test_paragraph
-    assert FFaker::LoremCN.paragraph.length >= 3 * 4 * 2
+    assert_greater_than_or_equal_to FFaker::LoremCN.paragraph.length, 3 * 4 * 2
   end
 
   def test_sentence
-    assert FFaker::LoremCN.sentence.length >= 4 * 2
+    assert_greater_than_or_equal_to FFaker::LoremCN.sentence.length, 4 * 2
   end
 
   def test_paragraphs
-    assert FFaker::LoremCN.paragraphs.length >= 2
+    assert_greater_than_or_equal_to FFaker::LoremCN.paragraphs.length, 2
   end
 
   def test_paragraphs_is_not_a_string_representation_of_an_array
@@ -31,7 +31,7 @@ class TestLoremCN < Test::Unit::TestCase
   end
 
   def test_sentences
-    assert FFaker::LoremCN.sentences.length >= 2
+    assert_greater_than_or_equal_to FFaker::LoremCN.sentences.length, 2
   end
 
   def test_sentences_is_an_array
@@ -45,10 +45,10 @@ class TestLoremCN < Test::Unit::TestCase
   end
 
   def test_words
-    assert FFaker::LoremCN.words.length >= 2
+    assert_greater_than_or_equal_to FFaker::LoremCN.words.length, 2
   end
 
   def test_word
-    assert FFaker::LoremCN.word.length >= 1
+    assert_greater_than_or_equal_to FFaker::LoremCN.word.length, 1
   end
 end
