@@ -1,13 +1,13 @@
-# encoding: utf-8
+# frozen_string_literal: true
 
 require 'helper'
 
 class TestLoremKR < Test::Unit::TestCase
   include DeterministicHelper
 
-  KOREAN_SENTENCE_MATCHER = /\A[ .가-힣]+\z/
-  KOREAN_WORDS_MATCHER = /\A[ 가-힣]+\z/
-  KOREAN_WORD_MATCHER = /\A[가-힣]+\z/
+  KOREAN_SENTENCE_MATCHER = /\A[ .가-힣]+\z/.freeze
+  KOREAN_WORDS_MATCHER = /\A[ 가-힣]+\z/.freeze
+  KOREAN_WORD_MATCHER = /\A[가-힣]+\z/.freeze
 
   assert_methods_are_deterministic(
     FFaker::LoremKR,
