@@ -1,4 +1,3 @@
-# encoding: utf-8
 # frozen_string_literal: true
 
 require 'helper'
@@ -6,9 +5,9 @@ require 'helper'
 class TestLoremRU < Test::Unit::TestCase
   include DeterministicHelper
 
-  SENTENCE_MATCHER = /\A[а-яА-ЯёЁ\-\s\.\!\?,]+\z/
-  WORDS_MATCHER    = /\A[А-Яа-яёЁ\-\s]+\z/
-  WORD_MATCHER     = /\A[А-Яа-яёЁ\-]+\z/
+  SENTENCE_MATCHER = /\A[а-яА-ЯёЁ\-\s\.\!\?,]+\z/.freeze
+  WORDS_MATCHER    = /\A[А-Яа-яёЁ\-\s]+\z/.freeze
+  WORD_MATCHER     = /\A[А-Яа-яёЁ\-]+\z/.freeze
 
   assert_methods_are_deterministic(
     FFaker::LoremRU,
