@@ -1,11 +1,11 @@
-# encoding: utf-8
+# frozen_string_literal: true
 
 require 'helper'
 
 class TestFakerNamePH < Test::Unit::TestCase
   include DeterministicHelper
 
-  PH_REGEXP = /\A([\wñÑú-]+\.? ?){2,5}\z/
+  PH_REGEXP = /\A([\wñÑú-]+\.? ?){2,5}\z/.freeze
 
   assert_methods_are_deterministic(
     FFaker::NamePH,
