@@ -1,8 +1,8 @@
-# encoding: utf-8
+# frozen_string_literal: true
 
 require 'helper'
 
-class TestPhoneNumer < Test::Unit::TestCase
+class TestPhoneNumber < Test::Unit::TestCase
   include DeterministicHelper
 
   assert_methods_are_deterministic(
