@@ -1,8 +1,7 @@
-# encoding: utf-8
+# frozen_string_literal: true
 
 require 'helper'
 
-# Author: Luilver<luilver@gmail.com>
 class TestPhoneNumberCU < Test::Unit::TestCase
   include DeterministicHelper
 
@@ -19,30 +18,26 @@ class TestPhoneNumberCU < Test::Unit::TestCase
     @tester = FFaker::PhoneNumberCU
   end
 
-  # Prefix format test
-  #
   def test_mobile_phone_prefix
-    assert FFaker::PhoneNumberCU::MobileOperatorsPrefix.include?(
+    assert FFaker::PhoneNumberCU::MOBILE_OPERATORS_PREFIX.include?(
       @tester.mobile_phone_prefix
     )
   end
 
   def test_home_work_phone_prefix
-    assert FFaker::PhoneNumberCU::HomeWorkOperatorsPrefix.include?(
+    assert FFaker::PhoneNumberCU::HOME_WORK_OPERATORS_PREFIX.include?(
       @tester.home_work_phone_prefix
     )
   end
 
   def test_phone_prefix
     10.times do
-      assert FFaker::PhoneNumberCU::OperatorsPrefix.include?(
+      assert FFaker::PhoneNumberCU::OPERATORS_PREFIX.include?(
         @tester.phone_prefix
       )
     end
   end
 
-  # General format test
-  #
   def test_mobile_phone_number
     assert_match(/05 \d{3} \d{4}/,
                  FFaker::PhoneNumberCU.mobile_phone_number)
@@ -60,8 +55,6 @@ class TestPhoneNumberCU < Test::Unit::TestCase
     end
   end
 
-  # International format tests
-  #
   def test_international_mobile_phone_number
     assert_match(/(00|\+)535 \d{3} \d{4}/,
                  FFaker::PhoneNumberCU.international_mobile_phone_number)
